function Animalcules ( NumberOfParticles, ParticleDiameter, PixelSize )
    if( nargin < 3 )
        PixelSize = 250e-9; % m
    end
    
    if( nargin < 2 )
        ParticleDiameter = 1e-6; % m
    end
    
    if( nargin < 1 )
        NumberOfParticles = 5;
    end

    close all
    
    imageSize = 300;
    frameInterval = 0.05;    % sec
    viscosity  = 1.0e-3;    % viscosity of water in SI units (Pascal-seconds) at 293 K
    temperatureKelvin = 293;
    boltzmannConstant   = 1.38e-23;

    diffusionCoefficient = boltzmannConstant * temperatureKelvin / ( 3 * pi * viscosity * ParticleDiameter );
    displacementStandardDeviation = sqrt( diffusionCoefficient * 2 * frameInterval );
    
    goodStart = false;
    while( ~goodStart )
        centroids = rand( NumberOfParticles, 2 ) * (imageSize-30) + 15; %not on border
        goodStart = min( pdist( centroids ) ) > 3 * ParticleDiameter / PixelSize;
    end

    while(1) %change this to number of frames
        frame = SimulatedFluorescenntParticleImage( centroids, 300, ParticleDiameter / 2 / PixelSize, [ imageSize imageSize ] );
        frame = frame./max(frame(:)); %normalize pixel intensity
        imagesc(frame)
        colormap gray
        axis equal
        axis off
        drawnow
        centroids = centroids + displacementStandardDeviation / PixelSize * randn( size( centroids ) );
    end
end